==> openjdk13-13.0.13_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_ms.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_ms extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "CAD", "CAD" },
            { "MXN", "MXN" },
            { "MYR", "RM" },
            { "USD", "USD" },
            { "aed", "Dirham Emiriah Arab Bersatu" },
            { "afn", "Afghani Afghanistan" },
            { "all", "Lek Albania" },
            { "amd", "Dram Armenia" },
            { "ang", "Guilder Antillen Belanda" },
            { "aoa", "Kwanza Angola" },
            { "ars", "Peso Argentina" },
            { "aud", "Dolar Australia" },
            { "awg", "Florin Aruba" },
            { "azn", "Manat Azerbaijan" },
            { "bam", "Mark Boleh Tukar Bosnia-Herzegovina" },
            { "bbd", "Dolar Barbados" },
            { "bdt", "Taka Bangladesh" },
            { "bgn", "Lev Bulgaria" },
            { "bhd", "Dinar Bahrain" },
            { "bif", "Franc Burundi" },
            { "bmd", "Dolar Bermuda" },
            { "bnd", "Dolar Brunei" },
            { "bob", "Boliviano Bolivia" },
            { "brl", "Real Brazil" },
            { "bsd", "Dolar Bahamas" },
            { "btn", "Ngultrum Bhutan" },
            { "bwp", "Pula Botswana" },
            { "byn", "Rubel Belarus baharu" },
            { "byr", "Rubel Belarus (2000\u20132016)" },
            { "bzd", "Dolar Belize" },
            { "cad", "Dolar Kanada" },
            { "cdf", "Franc Congo" },
            { "chf", "Franc Switzerland" },
            { "clp", "Peso Chile" },
            { "cnh", "Yuan China (luar pesisir)" },
            { "cny", "Yuan Cina" },
            { "cop", "Peso Colombia" },
            { "crc", "Colon Costa Rica" },
            { "cuc", "Peso Boleh Tukar Cuba" },
            { "cup", "Peso Cuba" },
            { "cve", "Escudo Tanjung Verde" },
            { "czk", "Koruna Republik Czech" },
            { "djf", "Franc Djibouti" },
            { "dkk", "Krone Denmark" },
            { "dop", "Peso Dominican" },
            { "dzd", "Dinar Algeria" },
            { "egp", "Paun Mesir" },
            { "ern", "ERN" },
            { "etb", "Birr Ethiopia" },
            { "eur", "Euro" },
            { "fjd", "Dolar Fiji" },
            { "fkp", "Paun Kepulauan Falkland" },
            { "gbp", "Paun British" },
            { "gel", "Lari Georgia" },
            { "ghs", "Cedi Ghana" },
            { "gip", "Paun Gibraltar" },
            { "gmd", "Dalasi Gambia" },
            { "gnf", "Franc Guinea" },
            { "gtq", "Quetzal Guatemala" },
            { "gyd", "Dolar Guyana" },
            { "hkd", "Dolar Hong Kong" },
            { "hnl", "Lempira Honduras" },
            { "hrk", "Kuna Croatia" },
            { "htg", "Gourde Haiti" },
            { "huf", "Forint Hungary" },
            { "idr", "Rupiah Indonesia" },
            { "ils", "Syekel Baharu Israel" },
            { "inr", "Rupee India" },
            { "iqd", "Dinar Iraq" },
            { "irr", "Rial Iran" },
            { "isk", "Krona Iceland" },
            { "jmd", "Dolar Jamaica" },
            { "jod", "Dinar Jordan" },
            { "jpy", "Yen Jepun" },
            { "kes", "Syiling Kenya" },
            { "kgs", "Som Kyrgystani" },
            { "khr", "Riel Kemboja" },
            { "kmf", "Franc Comoria" },
            { "kpw", "Won Korea Utara" },
            { "krw", "Won Korea Selatan" },
            { "kwd", "Dinar Kuwait" },
            { "kyd", "Dolar Kepulauan Cayman" },
            { "kzt", "Tenge Kazakhstan" },
            { "lak", "Kip Laos" },
            { "lbp", "Paun Lubnan" },
            { "lkr", "Rupee Sri Lanka" },
            { "lrd", "Dolar Liberia" },
            { "lsl", "Loti Lesotho" },
            { "ltl", "Litas Lithuania" },
            { "lvl", "Lats Latvia" },
            { "lyd", "Dinar Libya" },
            { "mad", "Dirham Maghribi" },
            { "mdl", "Leu Moldova" },
            { "mga", "Ariary Malagasy" },
            { "mkd", "Denar Macedonia" },
            { "mmk", "Kyat Myanma" },
            { "mnt", "Tugrik Mongolia" },
            { "mop", "Pataca Macau" },
            { "mro", "Ouguiya Mauritania (1973\u20132017)" },
            { "mru", "Ouguiya Mauritania" },
            { "mur", "Rupee Mauritius" },
            { "mvr", "Rufiyaa Maldives" },
            { "mwk", "Kwacha Malawi" },
            { "mxn", "Peso Mexico" },
            { "myr", "Ringgit Malaysia" },
            { "mzn", "Metikal Mozambique" },
            { "nad", "Dolar Namibia" },
            { "ngn", "Naira Nigeria" },
            { "nio", "Cordoba Nicaragua" },
            { "nok", "Krone Norway" },
            { "npr", "Rupee Nepal" },
            { "nzd", "Dolar New Zealand" },
            { "omr", "Rial Oman" },
            { "pab", "Balboa Panama" },
            { "pen", "Sol Peru" },
            { "pgk", "Kina Papua New Guinea" },
            { "php", "Peso Filipina" },
            { "pkr", "Rupee Pakistan" },
            { "pln", "Zloty Poland" },
            { "pyg", "Guarani Paraguay" },
            { "qar", "Rial Qatar" },
            { "ron", "Leu Romania" },
            { "rsd", "Dinar Serbia" },
            { "rub", "Rubel Rusia" },
            { "rwf", "Franc Rwanda" },
            { "sar", "Riyal Saudi" },
            { "sbd", "Dolar Kepulauan Solomon" },
            { "scr", "Rupee Seychelles" },
            { "sdg", "Paun Sudan" },
            { "sek", "Krona Sweden" },
            { "sgd", "Dolar Singapura" },
            { "shp", "Paun Saint Helena" },
            { "sll", "Leone Sierra Leone" },
            { "sos", "Syiling Somali" },
            { "srd", "Dolar Surinam" },
            { "ssp", "Paun Sudan selatan" },
            { "std", "Dobra Sao Tome dan Principe (1977\u20132017)" },
            { "stn", "Dobra Sao Tome dan Principe" },
            { "syp", "Paun Syria" },
            { "szl", "Lilangeni Swazi" },
            { "thb", "Baht Thai" },
            { "tjs", "Somoni Tajikistan" },
            { "tmt", "Manat Turkmenistan" },
            { "tnd", "Dinar Tunisia" },
            { "top", "Pa\u2019anga Tonga" },
            { "try", "Lira Turki" },
            { "ttd", "Dolar Trinidad dan Tobago" },
            { "twd", "Dolar Taiwan Baru" },
            { "tzs", "Syiling Tanzania" },
            { "uah", "Hryvnia Ukraine" },
            { "ugx", "Syiling Uganda" },
            { "usd", "Dolar AS" },
            { "uyu", "Peso Uruguay" },
            { "uzs", "Som Uzbekistan" },
            { "vef", "Bolivar Venezuela (2008\u20132018)" },
            { "ves", "Bolivar Venezuela" },
            { "vnd", "Dong Vietnam" },
            { "vuv", "Vatu Vanuatu" },
            { "wst", "Tala Samoa" },
            { "xaf", "Franc CFA BEAC" },
            { "xcd", "Dolar Caribbean Timur" },
            { "xof", "Franc CFA BCEAO" },
            { "xpf", "Franc CFP" },
            { "xxx", "Mata Wang Tidak Diketahui" },
            { "yer", "Rial Yaman" },
            { "zar", "Rand Afrika Selatan" },
            { "zmk", "Kwacha Zambia (1968\u20132012)" },
            { "zmw", "Kwacha Zambia" },
        };
        return data;
    }
}

==> openjdk15-15.0.9_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_ms.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_ms extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CAD", "CAD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LTL", "LTL" },
            { "LVL", "LVL" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MXN", "MXN" },
            { "MYR", "RM" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "THB" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "USD", "USD" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMK", "ZMK" },
            { "ZMW", "ZMW" },
            { "aed", "Dirham Emiriah Arab Bersatu" },
            { "afn", "Afghani Afghanistan" },
            { "all", "Lek Albania" },
            { "amd", "Dram Armenia" },
            { "ang", "Guilder Antillen Belanda" },
            { "aoa", "Kwanza Angola" },
            { "ars", "Peso Argentina" },
            { "aud", "Dolar Australia" },
            { "awg", "Florin Aruba" },
            { "azn", "Manat Azerbaijan" },
            { "bam", "Mark Boleh Tukar Bosnia-Herzegovina" },
            { "bbd", "Dolar Barbados" },
            { "bdt", "Taka Bangladesh" },
            { "bgn", "Lev Bulgaria" },
            { "bhd", "Dinar Bahrain" },
            { "bif", "Franc Burundi" },
            { "bmd", "Dolar Bermuda" },
            { "bnd", "Dolar Brunei" },
            { "bob", "Boliviano Bolivia" },
            { "brl", "Real Brazil" },
            { "bsd", "Dolar Bahamas" },
            { "btn", "Ngultrum Bhutan" },
            { "bwp", "Pula Botswana" },
            { "byn", "Rubel Belarus baharu" },
            { "byr", "Rubel Belarus (2000\u20132016)" },
            { "bzd", "Dolar Belize" },
            { "cad", "Dolar Kanada" },
            { "cdf", "Franc Congo" },
            { "chf", "Franc Switzerland" },
            { "clp", "Peso Chile" },
            { "cnh", "Yuan China (luar pesisir)" },
            { "cny", "Yuan Cina" },
            { "cop", "Peso Colombia" },
            { "crc", "Colon Costa Rica" },
            { "cuc", "Peso Boleh Tukar Cuba" },
            { "cup", "Peso Cuba" },
            { "cve", "Escudo Tanjung Verde" },
            { "czk", "Koruna Republik Czech" },
            { "djf", "Franc Djibouti" },
            { "dkk", "Krone Denmark" },
            { "dop", "Peso Dominican" },
            { "dzd", "Dinar Algeria" },
            { "egp", "Paun Mesir" },
            { "ern", "Nakfa Eritrea" },
            { "etb", "Birr Ethiopia" },
            { "eur", "Euro" },
            { "fjd", "Dolar Fiji" },
            { "fkp", "Paun Kepulauan Falkland" },
            { "gbp", "Paun British" },
            { "gel", "Lari Georgia" },
            { "ghs", "Cedi Ghana" },
            { "gip", "Paun Gibraltar" },
            { "gmd", "Dalasi Gambia" },
            { "gnf", "Franc Guinea" },
            { "gtq", "Quetzal Guatemala" },
            { "gyd", "Dolar Guyana" },
            { "hkd", "Dolar Hong Kong" },
            { "hnl", "Lempira Honduras" },
            { "hrk", "Kuna Croatia" },
            { "htg", "Gourde Haiti" },
            { "huf", "Forint Hungary" },
            { "idr", "Rupiah Indonesia" },
            { "ils", "Syekel Baharu Israel" },
            { "inr", "Rupee India" },
            { "iqd", "Dinar Iraq" },
            { "irr", "Rial Iran" },
            { "isk", "Krona Iceland" },
            { "jmd", "Dolar Jamaica" },
            { "jod", "Dinar Jordan" },
            { "jpy", "Yen Jepun" },
            { "kes", "Syiling Kenya" },
            { "kgs", "Som Kyrgystani" },
            { "khr", "Riel Kemboja" },
            { "kmf", "Franc Comoria" },
            { "kpw", "Won Korea Utara" },
            { "krw", "Won Korea Selatan" },
            { "kwd", "Dinar Kuwait" },
            { "kyd", "Dolar Kepulauan Cayman" },
            { "kzt", "Tenge Kazakhstan" },
            { "lak", "Kip Laos" },
            { "lbp", "Paun Lubnan" },
            { "lkr", "Rupee Sri Lanka" },
            { "lrd", "Dolar Liberia" },
            { "lsl", "Loti Lesotho" },
            { "ltl", "Litas Lithuania" },
            { "lvl", "Lats Latvia" },
            { "lyd", "Dinar Libya" },
            { "mad", "Dirham Maghribi" },
            { "mdl", "Leu Moldova" },
            { "mga", "Ariary Malagasy" },
            { "mgf", "Franc Malagasy" },
            { "mkd", "Denar Macedonia" },
            { "mmk", "Kyat Myanma" },
            { "mnt", "Tugrik Mongolia" },
            { "mop", "Pataca Macau" },
            { "mro", "Ouguiya Mauritania (1973\u20132017)" },
            { "mru", "Ouguiya Mauritania" },
            { "mur", "Rupee Mauritius" },
            { "mvr", "Rufiyaa Maldives" },
            { "mwk", "Kwacha Malawi" },
            { "mxn", "Peso Mexico" },
            { "myr", "Ringgit Malaysia" },
            { "mze", "Escudo Mozambique" },
            { "mzm", "Metical Mozambique (1980\u20132006)" },
            { "mzn", "Metikal Mozambique" },
            { "nad", "Dolar Namibia" },
            { "ngn", "Naira Nigeria" },
            { "nio", "Cordoba Nicaragua" },
            { "nok", "Krone Norway" },
            { "npr", "Rupee Nepal" },
            { "nzd", "Dolar New Zealand" },
            { "omr", "Rial Oman" },
            { "pab", "Balboa Panama" },
            { "pen", "Sol Peru" },
            { "pgk", "Kina Papua New Guinea" },
            { "php", "Peso Filipina" },
            { "pkr", "Rupee Pakistan" },
            { "pln", "Zloty Poland" },
            { "pyg", "Guarani Paraguay" },
            { "qar", "Rial Qatar" },
            { "rhd", "Dolar Rhodesia" },
            { "ron", "Leu Romania" },
            { "rsd", "Dinar Serbia" },
            { "rub", "Rubel Rusia" },
            { "rwf", "Franc Rwanda" },
            { "sar", "Riyal Saudi" },
            { "sbd", "Dolar Kepulauan Solomon" },
            { "scr", "Rupee Seychelles" },
            { "sdg", "Paun Sudan" },
            { "sek", "Krona Sweden" },
            { "sgd", "Dolar Singapura" },
            { "shp", "Paun Saint Helena" },
            { "sll", "Leone Sierra Leone" },
            { "sos", "Syiling Somali" },
            { "srd", "Dolar Surinam" },
            { "ssp", "Paun Sudan selatan" },
            { "std", "Dobra Sao Tome dan Principe (1977\u20132017)" },
            { "stn", "Dobra Sao Tome dan Principe" },
            { "syp", "Paun Syria" },
            { "szl", "Lilangeni Swazi" },
            { "thb", "Baht Thai" },
            { "tjs", "Somoni Tajikistan" },
            { "tmt", "Manat Turkmenistan" },
            { "tnd", "Dinar Tunisia" },
            { "top", "Pa\u2019anga Tonga" },
            { "try", "Lira Turki" },
            { "ttd", "Dolar Trinidad dan Tobago" },
            { "twd", "Dolar Taiwan Baru" },
            { "tzs", "Syiling Tanzania" },
            { "uah", "Hryvnia Ukraine" },
            { "ugs", "Shilling Uganda (1966\u20131987)" },
            { "ugx", "Syiling Uganda" },
            { "usd", "Dolar AS" },
            { "uyu", "Peso Uruguay" },
            { "uzs", "Som Uzbekistan" },
            { "vef", "Bolivar Venezuela (2008\u20132018)" },
            { "ves", "Bolivar Venezuela" },
            { "vnd", "Dong Vietnam" },
            { "vuv", "Vatu Vanuatu" },
            { "wst", "Tala Samoa" },
            { "xaf", "Franc CFA BEAC" },
            { "xcd", "Dolar Caribbean Timur" },
            { "xof", "Franc CFA BCEAO" },
            { "xpf", "Franc CFP" },
            { "xxx", "Mata Wang Tidak Diketahui" },
            { "yer", "Rial Yaman" },
            { "zar", "Rand Afrika Selatan" },
            { "zmk", "Kwacha Zambia (1968\u20132012)" },
            { "zmw", "Kwacha Zambia" },
            { "zwd", "Dolar Zimbabwe (1980\u20132008)" },
            { "zwl", "Dolar Zimbabwe (2009)" },
            { "zwr", "Dolar Zimbabwe (2008)" },
        };
        return data;
    }
}
